Quality

Enum Quality 

#[repr(u32)]
pub enum Quality { Antialiased = 4, Default = 0, Draft = 1, NonAntialiased = 3, Proof = 2, }

Variants



Antialiased = 4

Font is always antialiased if the font supports it and the size of the font is not too small or too large.



Default = 0

Appearance of the font does not matter.



Draft = 1

Appearance of the font is less important than when PROOF_QUALITY is used. For GDI raster fonts, scaling is enabled, which means that more font sizes are available, but the quality may be lower. Bold, italic, underline, and strikeout fonts are synthesized if necessary.



NonAntialiased = 3

Font is never antialiased.



Proof = 2

Character quality of the font is more important than exact matching of the logical-font attributes. For GDI raster fonts, scaling is disabled and the font closest in size is chosen. Although the chosen font size may not be mapped exactly when PROOF_QUALITY is used, the quality of the font is high and there is no distortion of appearance. Bold, italic, underline, and strikeout fonts are synthesized if necessary.